@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from zope.interface import implements
-from zope.app.schema.vocabulary import IVocabularyFactory
+from zope.schema.interfaces import IVocabularyFactory
 from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm
 
 from collective.portlet.content import ContentPortletMessageFactory as _
